Module: Interactor::Declaration
- Extended by:
- ActiveSupport::Concern
- Included in:
- Interactor
- Defined in:
- lib/interactor/declaration.rb
Overview
Internal: Methods relating to declaring what we receive and what will be stored in the context.
Internal: Methods relating to declaring what we receive and what will be stored in the context.